<?php
/*
Plugin Name: Coa Plugin
Description: Coa is a powerful framework to create lean and functional templates. It provides the Coa language and some useful out of the box features for fast and flexible development.
Version: 1.5.1
Author: Benjamin Scherer
Author URI: http://www.plue.me/

Modified MIT License

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, and/or sublicense, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/


////////////////////
// Get Prepared
////////////////////

// get correct id for plugin
$thisfile = basename(__FILE__, '.php');

// register plugin
register_plugin(
  $thisfile,
  'Coa Plugin',
  '1.5.1',
  'Benjamin Scherer',
  'http://www.plue.me/',
  'Coa is a powerful framework to create lean and functional templates. It provides the Coa language and some useful out of the box features for fast and flexible development',
  'pages',
  'coa_plugin_main'
);

// add in this plugin's language file
i18n_merge($thisfile) || i18n_merge($thisfile, 'en_US') || i18n_merge($thisfile, 'de_DE');


////////////
// Hooks
////////////

// on edit page
if(strstr($_SERVER["REQUEST_URI"], 'edit.php')) {
  add_action('pages-sidebar','translate_button');
  add_action('footer','coa_edit_footer');
}
add_action('edit-extras', 'add_translation_extras',array());
add_action('edit-content', 'add_translation_editor',array());
add_action('changedata-save', 'change_data',array());

// on plugins page
#add_action('plugins-sidebar','createSideMenu',array($thisfile, i18n_r($thisfile.'/COA_SETTINGS')));


////////////////////
// Main Function
////////////////////

function coa_plugin_main() {
  echo '<h3>Coa Plugin</h3>
      <p>Future settings ...</p>
  ';
}


///////////////////////
// Translate Button
///////////////////////

function translate_button() {
  echo '<li id="sb_CoaPlugin"><a href="#">'.i18n_r('CoaPlugin/COA_EDIT_TRANSLATION').'</a></li>';
}


////////////////////////////
// Add Translation Extras
////////////////////////////

function add_translation_extras() {
  $id = isset($_GET['id']) ? $_GET['id'] : null;
  $path = GSDATAPAGESPATH;
  $file = $id .'.xml';
  
  $translation_title = '';
  $translation_menu = '';
  
  // get data
  $data_edit = getXML($path . $file);
  $translation_title = stripslashes($data_edit->translationTitle);
  $translation_menu = stripslashes($data_edit->translationMenu);

  echo '<link rel="stylesheet" href="../plugins/CoaPlugin/res/coa_backend.css"></link>';

  echo '<div id="extra_CoaPlugin">
    <p id="translation_title">
    <label for="post-title-translation">'.i18n_r('CoaPlugin/COA_TITLE_TRANSLATION').'</label>
    <input class="text short" id="post-title-translation" name="post-title-translation" type="text" value="'.$translation_title.'" />
    </p>
    <p id="translation_menu">
    <label for="post-menu-translation">'.i18n_r('CoaPlugin/COA_MENU_TRANSLATION').'</label>
    <input class="text short" id="post-menu-translation" name="post-menu-translation" type="text" value="'.$translation_menu.'" />
    </p>
    <div class="clear"></div>
    </div>';
}


////////////////////////////
// Add Translation Editor
////////////////////////////

function add_translation_editor() {
  $id = isset($_GET['id']) ? $_GET['id'] : null;
  $path = GSDATAPAGESPATH;
  $file = $id .'.xml';
  $translation = '';
  
  // get data
  $data_edit = getXML($path . $file);
  $translation = $data_edit->translationContent;
  
  echo '<textarea id="post-content-translation" name="post-content-translation">'. $translation .'</textarea>';
}


////////////////////////////
// Save Page Translation
////////////////////////////

function change_data() {
  global $note, $xml;
  
  // get post vars
  $POST_title = $_POST['post-title-translation'];
  $POST_menu = $_POST['post-menu-translation'];
  $POST_content = $_POST['post-content-translation'];
  
  // save title
  if(isset($POST_title) && $POST_title != '') {
    $translation_title = safe_slash_html($POST_title);
    $note = $xml->addChild('translationTitle');
    $note->addCData($translation_title);
  }

  // save menu title
  if(isset($POST_menu) && $POST_menu != '') {
    $translation_menu = safe_slash_html($POST_menu);
    $note = $xml->addChild('translationMenu');
    $note->addCData($translation_menu);
  }
  
  // save content
  if(isset($POST_content) && $POST_content != '') {
    $translation = safe_slash_html($POST_content);
    $note = $xml->addChild('translationContent');
    $note->addCData($translation);
  }
}


///////////////////////
// Edit Page Footer
///////////////////////

function coa_edit_footer() {
  global $SITEURL, $HTMLEDITOR, $TEMPLATE;
  
  // get editor constants
  if (defined('GSEDITORHEIGHT')) { $EDHEIGHT = GSEDITORHEIGHT .'px'; } else {  $EDHEIGHT = '500px'; }
  if (defined('GSEDITORLANG')) { $EDLANG = GSEDITORLANG; } else {  $EDLANG = i18n_r('CKEDITOR_LANG'); }
  if (defined('GSEDITORTOOL')) { $EDTOOL = GSEDITORTOOL; } else {  $EDTOOL = 'basic'; }
  if (defined('GSEDITOROPTIONS') && trim(GSEDITOROPTIONS)!="") { $EDOPTIONS = ", ".GSEDITOROPTIONS; } else {  $EDOPTIONS = ''; }
  
  // define toolbar
  if ($EDTOOL == 'advanced') {
    $toolbar = "['Bold', 'Italic', 'Underline', 'NumberedList', 'BulletedList', 'JustifyLeft','JustifyCenter'".
      ",'JustifyRight','JustifyBlock', 'Table', 'TextColor', 'BGColor', 'Link', 'Unlink', 'Image', 'RemoveFormat',".
      "'Source'], '/', ['Styles','Format','Font','FontSize']";
  } elseif ($EDTOOL == 'basic') {
    $toolbar = "['Bold', 'Italic', 'Underline', 'NumberedList', 'BulletedList', 'JustifyLeft','JustifyCenter',".
      "'JustifyRight','JustifyBlock', 'Link', 'Unlink', 'Image', 'RemoveFormat', 'Source']";
  } else {
    $toolbar = GSEDITORTOOL;
  }
  
  // enable html editor
  if ($HTMLEDITOR != '') {
    echo '<script type="text/javascript">
      var editor = CKEDITOR.replace( \'post-content-translation\', {
      skin : \'getsimple\',
      forcePasteAsPlainText : true,
      language : \''.$EDLANG.'\',
      defaultLanguage : \'en\',';
        
    if (file_exists(GSTHEMESPATH .$TEMPLATE."/editor.css")) { 
      $fullpath = suggest_site_path();
      echo 'contentsCss: \''.$fullpath.'theme/'.$TEMPLATE.'/editor.css\',';
    }
    
    echo 'entities : false,
      uiColor: \'#FFFFFF\',
      height: \''.$EDHEIGHT.'\',
      baseHref: \''.$SITEURL.'\',
      toolbar: ['.$toolbar.']
      '.$EDOPTIONS.',
      tabSpaces:10,
      filebrowserBrowseUrl : \'filebrowser.php?type=all\',
      filebrowserImageBrowseUrl : \'filebrowser.php?type=images\',
      filebrowserWindowWidth : \'730\',
      filebrowserWindowHeight : \'500\'
      });
      CKEDITOR.instances["post-content-translation"].on("instanceReady", InstanceReadyEvent);
      function InstanceReadyEvent() {
        this.document.on("keyup", function () {
          $(\'#editform\').trigger(\'change\');
        });
      }
      </script>';
  }
  
  // coa backend js
  echo '<script type="text/javascript" src="../plugins/CoaPlugin/res/coa.backend.js"></script>';
}
?>